==> opale_3.4.200-en.tgz: bin/scApp/chrome/mEmbdSrv/app.extSource.js <==

                        Components.utils.import("chrome://scenariWsp/content/commons.jsm");
                        Components.utils.import("chrome://scenariWsp/content/commons/servers.jsm");
                        
                        const PREFS = Cc["@mozilla.org/preferences-service;1"].getService(Ci.nsIPrefBranch);
                        const PREFS_LASTVERSIONRUN       = "scenaripref.app.lastVersionRun"; 
                        
                        try {
                            //onload : Création des ateliers si premier lancement
                            extPoints.addToList("event:launchApp", "scApp:mEmbdSrv:createWsp", 1, function(pFcts, pOffset, pCmdLine){
                                var vVersion =  i18n.brandingSb.GetStringFromName('appVersion');
                                var vInstallLength = 0;
                                if(PREFS.getPrefType(PREFS_LASTVERSIONRUN)!=PREFS.PREF_STRING || PREFS.getCharPref(PREFS_LASTVERSIONRUN)!=vVersion){
                                    
                                    var fCallbackOnCreate = function(pOk){
                                    	vInstallLength--;
                                    	if(vInstallLength==0) extPoints.callFunctions(pFcts, pOffset+1, 3, this, [null,null,pCmdLine]);
                                    }
                                    
                                    var vServer;
                                    // Recherche/création du serveur local
                                    var vServers = servers.getRegistry().findServers(function(pServer){
                                        return pServer.isEmbedded();
                                    });
                                    if(vServers.length == 0) {
                                        vServer = servers.createEmbeddedServer(null, "EmbeddedScServerFs"); 
                                        servers.getRegistry().addServerToList(vServer, "emdFix");
                                    } else {
                                        vServer = vServers[0];
                                    }
                                    // Création des ateliers

                                                    var vLaunchContext = {};
                                                    vLaunchContext.callbackOnCreate = fCallbackOnCreate;
                                                    vLaunchContext.thisForCbOnCreate = this;
                                                    vLaunchContext.scServer = vServer;
                                                    vLaunchContext.createProperties = {};
                                                    vLaunchContext.createProperties.title="Opale";
                                                    vLaunchContext.createProperties.code="Opale";

                                                             //Construction du fichier wspmeta du freeWspDef
                                                             ///tmp/modules/mEmbdSrv/All/gecko/chrome/mEmbdSrv/wsptype/free/N5b.wsptype
                                                        	var vWsptypeUrl = "chrome://scmEmbeddedServer/content/wsptype/free/N5b.wsptype";

                                                    vLaunchContext.wspTypeUrl=vWsptypeUrl;
                                                    vInstallLength++;
                                                    extPoints.getSvc("wspCreator").createWspAuto(null, vLaunchContext);

                                    //On interrompt l'init si des installations vont démarrer...
									return vInstallLength==0;
                               }
                            }, -1);
                            
                             //onload : Ouverture des ateliers

                            
                            // Déclaration de l'action ouvrir l'atelier (fs uniquement)...

                                            var actionOpenWsp = new actions.Action("actionOpenWsp").setGroup("adminWsp").setLabel(i18n.formatStr("Open the \'%s\' workspace", "Opale")).setIcon("chrome://scenariWsp/content/views/serversView/ico16/viewWsp.png");
											actionOpenWsp.execute = function(pEvent, pContext){
												var vServers = servers.getRegistry().findServers(function(pServer){
													return pServer.getId()=="emdFix";
												});
												extPoints.getSvc("wspDesk").browseWsp({scServer: vServers[0], wspCode: "Opale"}, pContext.window);
											};
											actionOpenWsp.isVisible = function(pContext){
												var vServers = servers.getRegistry().findServers(function(pServer){
													return pServer.getId()=="emdFix";
												});
												return vServers.length>0;
											};
											actionOpenWsp.findDisplayScore = function(pContext, pCb, pCbThis){
												var vServers = servers.getRegistry().findServers(function(pServer){
													return pServer.getId()=="emdFix";
												});
												var vAction = this;
												if(!this._LastScore && vServers.length>0){
													function cbLoadWspList(pEvent){
														try{
															if(pEvent.target.status == 200){
																var vWspListXml = pEvent.target.responseXML;
																vAction._LastScore = (vWspListXml && dom.selectSingleNode(vWspListXml, "/wspList/wsp[@code='Opale']")) ? 100 : -1;
															}
														} catch(e){
															log.debug(e);
														}finally{
															if(pCb) pCb.call(pCbThis, vAction._LastScore || -1);
														}
													}
													vServers[0].getDataProvider().loadFromService("/u/adminWsp?cdaction=List", cbLoadWspList);
												}else{
													if(pCb) pCb.call(pCbThis, this._LastScore || -1);
												}
											};
											extPoints.registerSvcByInst("actionOpenWsp-Opale", 101, actionOpenWsp);
											extPoints.addSvcToList("tools:homeDesk:app", "actionOpenWsp-Opale", 101, "actionOpenWsp-Opale", 1);
                                            

                                    
                            
                            // Enregistrement de la version courante
                            extPoints.addToList("event:quitApp", "scApp:mEmbdSrv:saveLastVersion", 1, function(pFcts, pOffset){
                                var vVersion =  i18n.brandingSb.GetStringFromName('appVersion');
                                PREFS.setCharPref(PREFS_LASTVERSIONRUN, vVersion);
                           	}, 0);
                        } catch(e){
                            log.info("modEmbeddedServer > appExtSource ::: "+e);
                        }

==> opale_3.5.011-en.tgz: bin/scApp/chrome/mEmbdSrv/app.extSource.js <==

                        Components.utils.import("chrome://scenariWsp/content/commons.jsm");
                        Components.utils.import("chrome://scenariWsp/content/commons/servers.jsm");
                        
                        const PREFS = Cc["@mozilla.org/preferences-service;1"].getService(Ci.nsIPrefBranch);
                        const PREFS_LASTVERSIONRUN       = "scenaripref.app.lastVersionRun"; 
                        
                        try {
                            //onload : Création des ateliers si premier lancement
                            extPoints.addToList("event:launchApp", "scApp:mEmbdSrv:createWsp", 1, function(pFcts, pOffset, pCmdLine){
                                var vVersion =  i18n.brandingSb.GetStringFromName('appVersion');
                                var vInstallLength = 0;
                                if(PREFS.getPrefType(PREFS_LASTVERSIONRUN)!=PREFS.PREF_STRING || PREFS.getCharPref(PREFS_LASTVERSIONRUN)!=vVersion){
                                    
                                    var fCallbackOnCreate = function(pOk){
                                    	vInstallLength--;
                                    	if(vInstallLength==0) extPoints.callFunctions(pFcts, pOffset+1, 3, this, [null,null,pCmdLine]);
                                    }
                                    
                                    var vServer;
                                    // Recherche/création du serveur local
                                    var vServers = servers.getRegistry().findServers(function(pServer){
                                        return pServer.isEmbedded();
                                    });
                                    if(vServers.length == 0) {
                                        vServer = servers.createEmbeddedServer(null, "EmbeddedScServerFs"); 
                                        servers.getRegistry().addServerToList(vServer, "emdFix");
                                    } else {
                                        vServer = vServers[0];
                                    }
                                    // Création des ateliers

                                                    var vLaunchContext = {};
                                                    vLaunchContext.callbackOnCreate = fCallbackOnCreate;
                                                    vLaunchContext.thisForCbOnCreate = this;
                                                    vLaunchContext.scServer = vServer;
                                                    vLaunchContext.createProperties = {};
                                                    vLaunchContext.createProperties.title="Opale";
                                                    vLaunchContext.createProperties.code="Opale";

                                                             //Construction du fichier wspmeta du freeWspDef
                                                             ///tmp/modules/mEmbdSrv/All/gecko/chrome/mEmbdSrv/wsptype/free/N65.wsptype
                                                        	var vWsptypeUrl = "chrome://scmEmbeddedServer/content/wsptype/free/N65.wsptype";

                                                    vLaunchContext.wspTypeUrl=vWsptypeUrl;
                                                    vInstallLength++;
                                                    extPoints.getSvc("wspCreator").createWspAuto(null, vLaunchContext);

                                    //On interrompt l'init si des installations vont démarrer...
									return vInstallLength==0;
                               }
                            }, -1);
                            
                             //onload : Ouverture des ateliers

                            
                     		// Déclaration de l'action ouvrir l'atelier (fs uniquement)...

                                            var actionOpenWsp = new actions.Action("actionOpenWsp").setGroup("adminWsp").setLabel(i18n.formatStr("Open the \'%s\' workspace", "Opale")).setIcon("chrome://scenariWsp/content/views/serversView/ico16/viewWsp.png");
											actionOpenWsp.execute = function(pEvent, pContext){
												var vServers = servers.getRegistry().findServers(function(pServer){
													return pServer.getId()=="emdFix";
												});
												extPoints.getSvc("wspDesk").browseWsp({scServer: vServers[0], wspCode: "Opale"}, pContext.window);
											};
											actionOpenWsp.isVisible = function(pContext){
												var vServers = servers.getRegistry().findServers(function(pServer){
													return pServer.getId()=="emdFix";
												});
												return vServers.length>0;
											};
											actionOpenWsp.findDisplayScore = function(pContext, pCb, pCbThis){
												var vServers = servers.getRegistry().findServers(function(pServer){
													return pServer.getId()=="emdFix";
												});
												var vAction = this;
												if(!this._LastScore && vServers.length>0){
													function cbLoadWspList(pEvent){
														try{
															if(pEvent.target.status == 200){
																var vWspListXml = pEvent.target.responseXML;
																vAction._LastScore = (vWspListXml && dom.selectSingleNode(vWspListXml, "/wspList/wsp[@code='Opale']")) ? 100 : -1;
															}
														} catch(e){
															log.debug(e);
														}finally{
															if(pCb) pCb.call(pCbThis, vAction._LastScore || -1);
														}
													}
													vServers[0].getDataProvider().loadFromService("/u/adminWsp?cdaction=List", cbLoadWspList);
												}else{
													if(pCb) pCb.call(pCbThis, this._LastScore || -1);
												}
											};
											extPoints.registerSvcByInst("actionOpenWsp-Opale", 101, actionOpenWsp);
											extPoints.addSvcToList("tools:homeDesk:app", "actionOpenWsp-Opale", 101, "actionOpenWsp-Opale", 1);
                                            

                            
                            // Enregistrement de la version courante
                            extPoints.addToList("event:quitApp", "scApp:mEmbdSrv:saveLastVersion", 1, function(pFcts, pOffset){
                                var vVersion =  i18n.brandingSb.GetStringFromName('appVersion');
                                PREFS.setCharPref(PREFS_LASTVERSIONRUN, vVersion);
                           	}, 0);
                        } catch(e){
                            log.info("modEmbeddedServer > appExtSource ::: "+e);
                        }
